@@ -12,16 +12,14 @@ log = tuned.logs.get()
 
 class SystemdPlugin(base.Plugin):
 	"""
-	`systemd`::
-	
 	Plug-in for tuning systemd options.
-	+
+
 	The [option]`cpu_affinity` option allows setting CPUAffinity in
 	`/etc/systemd/system.conf`. This configures the CPU affinity for the
 	service manager as well as the default CPU affinity for all forked
 	off processes. The option takes a comma-separated list of CPUs with
 	optional CPU ranges specified by the minus sign (`-`).
-	+
+
 	.Set the CPUAffinity for `systemd` to `0 1 2 3`
 	====
 	----
@@ -29,7 +27,7 @@ class SystemdPlugin(base.Plugin):
 	cpu_affinity=0-3
 	----
 	====
-	+
+
 	NOTE: These tunings are unloaded only on profile change followed by a reboot.
 	"""
 
@@ -111,8 +109,8 @@ class SystemdPlugin(base.Plugin):
 				conf = self._add_keyval(conf, consts.SYSTEMD_CPUAFFINITY_VAR, cpu_affinity_saved)
 			self._write_systemd_system_conf(conf)
 
-	def _instance_unapply_static(self, instance, full_rollback = False):
-		if full_rollback:
+	def _instance_unapply_static(self, instance, rollback = consts.ROLLBACK_SOFT):
+		if rollback == consts.ROLLBACK_FULL:
 			log.info("removing '%s' systemd tuning previously added by TuneD" % consts.SYSTEMD_CPUAFFINITY_VAR)
 			self._remove_systemd_tuning()
 			log.console("you may need to manualy run 'dracut -f' to update the systemd configuration in initrd image")
@@ -124,7 +122,7 @@ class SystemdPlugin(base.Plugin):
 		return " ".join(str(v) for v in self._cmd.cpulist_unpack(re.sub(r"\s+", r",", re.sub(r",\s+", r",", cpulist))))
 
 	@command_custom("cpu_affinity", per_device = False)
-	def _cmdline(self, enabling, value, verify, ignore_missing):
+	def _cmdline(self, enabling, value, verify, ignore_missing, instance):
 		conf_affinity = None
 		conf_affinity_unpacked = None
 		v = self._cmd.unescape(self._variables.expand(self._cmd.unquote(value)))
@@ -143,3 +141,6 @@ class SystemdPlugin(base.Plugin):
 
 			log.info("setting '%s' to '%s' in the '%s'" % (consts.SYSTEMD_CPUAFFINITY_VAR, v_unpacked, consts.SYSTEMD_SYSTEM_CONF_FILE))
 			self._write_systemd_system_conf(self._add_keyval(conf, consts.SYSTEMD_CPUAFFINITY_VAR, v_unpacked))
+			return True
+		return None
+
