@@ -1,6 +1,6 @@
 import os
 import tuned.logs
-import base
+from . import base
 from tuned.utils.commands import commands
 
 log = tuned.logs.get()
@@ -11,9 +11,9 @@ class cpulist_unpack(base.Function):
 	"""
 	def __init__(self):
 		# arbitrary number of arguments
-		super(self.__class__, self).__init__("cpulist_unpack", 0)
+		super(cpulist_unpack, self).__init__("cpulist_unpack", 0)
 
 	def execute(self, args):
-		if not super(self.__class__, self).execute(args):
+		if not super(cpulist_unpack, self).execute(args):
 			return None
 		return ",".join(str(v) for v in self._cmd.cpulist_unpack(",,".join(args)))
